# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.catalogs import family_pb2 as v1_dot_catalogs_dot_family__pb2


class FamilyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FamilyCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/FamilyCreate",
            request_serializer=v1_dot_catalogs_dot_family__pb2.FamilyCreateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.FamilyCreateResponse.FromString,
        )
        self.FamilyRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/FamilyRead",
            request_serializer=v1_dot_catalogs_dot_family__pb2.FamilyReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.FamilyReadResponse.FromString,
        )
        self.FamilyUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/FamilyUpdate",
            request_serializer=v1_dot_catalogs_dot_family__pb2.FamilyUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.FamilyUpdateResponse.FromString,
        )
        self.FamilyDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/FamilyDelete",
            request_serializer=v1_dot_catalogs_dot_family__pb2.FamilyDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.FamilyDeleteResponse.FromString,
        )
        self.GroupCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/GroupCreate",
            request_serializer=v1_dot_catalogs_dot_family__pb2.GroupCreateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.GroupCreateResponse.FromString,
        )
        self.GroupRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/GroupRead",
            request_serializer=v1_dot_catalogs_dot_family__pb2.GroupReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.GroupReadResponse.FromString,
        )
        self.GroupUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/GroupUpdate",
            request_serializer=v1_dot_catalogs_dot_family__pb2.GroupUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.GroupUpdateResponse.FromString,
        )
        self.GroupDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/GroupDelete",
            request_serializer=v1_dot_catalogs_dot_family__pb2.GroupDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.GroupDeleteResponse.FromString,
        )
        self.AttributeCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeCreate",
            request_serializer=v1_dot_catalogs_dot_family__pb2.AttributeCreateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeCreateResponse.FromString,
        )
        self.AttributeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeRead",
            request_serializer=v1_dot_catalogs_dot_family__pb2.AttributeReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeReadResponse.FromString,
        )
        self.AttributeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeUpdate",
            request_serializer=v1_dot_catalogs_dot_family__pb2.AttributeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeUpdateResponse.FromString,
        )
        self.AttributeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeDelete",
            request_serializer=v1_dot_catalogs_dot_family__pb2.AttributeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeDeleteResponse.FromString,
        )
        self.AttributeVariantCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeVariantCreate",
            request_serializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantCreateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantCreateResponse.FromString,
        )
        self.AttributeVariantRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeVariantRead",
            request_serializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantReadResponse.FromString,
        )
        self.AttributeVariantUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeVariantUpdate",
            request_serializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantUpdateResponse.FromString,
        )
        self.AttributeVariantDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeVariantDelete",
            request_serializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantDeleteResponse.FromString,
        )
        self.CategoryRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/CategoryRead",
            request_serializer=v1_dot_catalogs_dot_family__pb2.CategoryReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_family__pb2.CategoryReadResponse.FromString,
        )


class FamilyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FamilyCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FamilyRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FamilyUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FamilyDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GroupCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GroupRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GroupUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GroupDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttributeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttributeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttributeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttributeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttributeVariantCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttributeVariantRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttributeVariantUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttributeVariantDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CategoryRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_FamilyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "FamilyCreate": grpc.unary_unary_rpc_method_handler(
            servicer.FamilyCreate,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.FamilyCreateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.FamilyCreateResponse.SerializeToString,
        ),
        "FamilyRead": grpc.unary_unary_rpc_method_handler(
            servicer.FamilyRead,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.FamilyReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.FamilyReadResponse.SerializeToString,
        ),
        "FamilyUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.FamilyUpdate,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.FamilyUpdateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.FamilyUpdateResponse.SerializeToString,
        ),
        "FamilyDelete": grpc.unary_unary_rpc_method_handler(
            servicer.FamilyDelete,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.FamilyDeleteRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.FamilyDeleteResponse.SerializeToString,
        ),
        "GroupCreate": grpc.unary_unary_rpc_method_handler(
            servicer.GroupCreate,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.GroupCreateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.GroupCreateResponse.SerializeToString,
        ),
        "GroupRead": grpc.unary_unary_rpc_method_handler(
            servicer.GroupRead,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.GroupReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.GroupReadResponse.SerializeToString,
        ),
        "GroupUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.GroupUpdate,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.GroupUpdateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.GroupUpdateResponse.SerializeToString,
        ),
        "GroupDelete": grpc.unary_unary_rpc_method_handler(
            servicer.GroupDelete,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.GroupDeleteRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.GroupDeleteResponse.SerializeToString,
        ),
        "AttributeCreate": grpc.unary_unary_rpc_method_handler(
            servicer.AttributeCreate,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeCreateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.AttributeCreateResponse.SerializeToString,
        ),
        "AttributeRead": grpc.unary_unary_rpc_method_handler(
            servicer.AttributeRead,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.AttributeReadResponse.SerializeToString,
        ),
        "AttributeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.AttributeUpdate,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeUpdateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.AttributeUpdateResponse.SerializeToString,
        ),
        "AttributeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.AttributeDelete,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeDeleteRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.AttributeDeleteResponse.SerializeToString,
        ),
        "AttributeVariantCreate": grpc.unary_unary_rpc_method_handler(
            servicer.AttributeVariantCreate,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantCreateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantCreateResponse.SerializeToString,
        ),
        "AttributeVariantRead": grpc.unary_unary_rpc_method_handler(
            servicer.AttributeVariantRead,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantReadResponse.SerializeToString,
        ),
        "AttributeVariantUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.AttributeVariantUpdate,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantUpdateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantUpdateResponse.SerializeToString,
        ),
        "AttributeVariantDelete": grpc.unary_unary_rpc_method_handler(
            servicer.AttributeVariantDelete,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantDeleteRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.AttributeVariantDeleteResponse.SerializeToString,
        ),
        "CategoryRead": grpc.unary_unary_rpc_method_handler(
            servicer.CategoryRead,
            request_deserializer=v1_dot_catalogs_dot_family__pb2.CategoryReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_family__pb2.CategoryReadResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.catalogs.family.FamilyService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class FamilyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FamilyCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/FamilyCreate",
            v1_dot_catalogs_dot_family__pb2.FamilyCreateRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.FamilyCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FamilyRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/FamilyRead",
            v1_dot_catalogs_dot_family__pb2.FamilyReadRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.FamilyReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FamilyUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/FamilyUpdate",
            v1_dot_catalogs_dot_family__pb2.FamilyUpdateRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.FamilyUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FamilyDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/FamilyDelete",
            v1_dot_catalogs_dot_family__pb2.FamilyDeleteRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.FamilyDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GroupCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/GroupCreate",
            v1_dot_catalogs_dot_family__pb2.GroupCreateRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.GroupCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GroupRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/GroupRead",
            v1_dot_catalogs_dot_family__pb2.GroupReadRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.GroupReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GroupUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/GroupUpdate",
            v1_dot_catalogs_dot_family__pb2.GroupUpdateRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.GroupUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GroupDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/GroupDelete",
            v1_dot_catalogs_dot_family__pb2.GroupDeleteRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.GroupDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttributeCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeCreate",
            v1_dot_catalogs_dot_family__pb2.AttributeCreateRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.AttributeCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttributeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeRead",
            v1_dot_catalogs_dot_family__pb2.AttributeReadRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.AttributeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttributeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeUpdate",
            v1_dot_catalogs_dot_family__pb2.AttributeUpdateRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.AttributeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttributeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeDelete",
            v1_dot_catalogs_dot_family__pb2.AttributeDeleteRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.AttributeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttributeVariantCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeVariantCreate",
            v1_dot_catalogs_dot_family__pb2.AttributeVariantCreateRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.AttributeVariantCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttributeVariantRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeVariantRead",
            v1_dot_catalogs_dot_family__pb2.AttributeVariantReadRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.AttributeVariantReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttributeVariantUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeVariantUpdate",
            v1_dot_catalogs_dot_family__pb2.AttributeVariantUpdateRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.AttributeVariantUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttributeVariantDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/AttributeVariantDelete",
            v1_dot_catalogs_dot_family__pb2.AttributeVariantDeleteRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.AttributeVariantDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CategoryRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.family.FamilyService/CategoryRead",
            v1_dot_catalogs_dot_family__pb2.CategoryReadRequest.SerializeToString,
            v1_dot_catalogs_dot_family__pb2.CategoryReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# create a decorator to check if the user has permission to access the resource
from enum import Enum, unique

from omni.pro.logger import LoggerTraceback, configure_logger
from omni.pro.microservice import MicroService
from omni.pro.protos.grpc_connector import Event, GRPClient
from omni.pro.protos.response import MessageResponse
from omni.pro.protos.v1.users import user_pb2

logger = configure_logger(name=__name__)


@unique
class Permission(Enum):
    CAN_CREATE_ACTION = "CAN_CREATE_ACTION"
    CAN_READ_ACTION = "CAN_READ_ACTION"
    CAN_UPDATE_ACTION = "CAN_UPDATE_ACTION"
    CAN_CREATE_ACCESS = "CAN_CREATE_ACCESS"
    CAN_UPDATE_ACCESS = "CAN_UPDATE_ACCESS"
    CAN_READ_ACCESS = "CAN_READ_ACCESS"
    CAN_DELETE_ACCESS = "CAN_DELETE_ACCESS"
    CAN_CREATE_GROUP = "CAN_CREATE_GROUP"
    CAN_READ_GROUP = "CAN_READ_GROUP"
    CAN_UPDATE_GROUP = "CAN_UPDATE_GROUP"
    CAN_DELETE_GROUP = "CAN_DELETE_GROUP"
    CAN_CREATE_USER = "CAN_CREATE_USER"
    CAN_UPDATE_USER = "CAN_UPDATE_USER"
    CAN_READ_USER = "CAN_READ_USER"
    CAN_DELETE_USER = "CAN_DELETE_USER"
    CAN_CHANGE_PASSWORD_USER = "CAN_CHANGE_PASSWORD_USER"
    CAN_CHANGE_EMAIL_USER = "CAN_CHANGE_EMAIL_USER"
    CAN_ACCESS_TO_GROUP = "CAN_ACCESS_TO_GROUP"
    CAN_REMOVE_ACCESS_FROM_GROUP = "CAN_REMOVE_ACCESS_FROM_GROUP"
    CAN_GROUP_TO_USER = "CAN_GROUP_TO_USER"
    CAN_REMOVE_GROUP_FROM_USER = "CAN_REMOVE_GROUP_FROM_USER"
    CAN_CREATE_FAMILY = "CAN_CREATE_FAMILY"
    CAN_UPDATE_FAMILY = "CAN_UPDATE_FAMILY"
    CAN_READ_FAMILY = "CAN_READ_FAMILY"
    CAN_DELETE_FAMILY = "CAN_DELETE_FAMILY"
    CAN_CREATE_ATTRIBUTE = "CAN_CREATE_ATTRIBUTE"
    CAN_UPDATE_ATTRIBUTE = "CAN_UPDATE_ATTRIBUTE"
    CAN_READ_ATTRIBUTE = "CAN_READ_ATTRIBUTE"
    CAN_DELETE_ATTRIBUTE = "CAN_DELETE_ATTRIBUTE"
    CAN_CREATE_ATTRIBUTE_GROUP = "CAN_CREATE_ATTRIBUTE_GROUP"
    CAN_UPDATE_ATTRIBUTE_GROUP = "CAN_UPDATE_ATTRIBUTE_GROUP"
    CAN_READ_ATTRIBUTE_GROUP = "CAN_READ_ATTRIBUTE_GROUP"
    CAN_DELETE_ATTRIBUTE_GROUP = "CAN_DELETE_ATTRIBUTE_GROUP"
    CAN_CREATE_CLIENT = "CAN_CREATE_CLIENT"
    CAN_UPDATE_CLIENT = "CAN_UPDATE_CLIENT"
    CAN_READ_CLIENT = "CAN_READ_CLIENT"
    CAN_DELETE_CLIENT = "CAN_DELETE_CLIENT"


def permission_required(permission_name: Permission, cls) -> callable:
    def decorador_func(funcion: callable) -> callable:
        def inner(instance, request, context):
            try:
                event = Event(
                    module_grpc="v1.users.user_pb2_grpc",
                    module_pb2="v1.users.user_pb2",
                    stub_classname="UsersServiceStub",
                    rpc_method="HasPermission",
                    request_class="HasPermissionRequest",
                    params={
                        "username": request.context.user,
                        "permission": permission_name.value,
                        "context": {"tenant": request.context.tenant},
                    },
                )
                response: user_pb2.HasPermissionResponse = None
                response, success = GRPClient(MicroService.SAAS_MS_USER.value).call_rpc_fuction(event)
                if not success or not response.has_permission:
                    return MessageResponse(cls).unauthorized_response()
            except Exception as e:
                LoggerTraceback.error("Permission required decorator exception", e, logger)
                return MessageResponse(cls).internal_response(message="Permission required decorator exception")
            c = funcion(instance, request, context)
            return c

        return inner

    return decorador_func


def sync_cognito_access(sync_allow_access):
    def decorador(funcion):
        def wrapper(*args, **kwargs):
            result = funcion(*args, **kwargs)
            sync_allow_access(result)
            return result

        return wrapper

    return decorador


# Definimos la función que queremos ejecutar al final
def sync_allow_access(result):
    try:
        logger.info("sync_allow_access")
        if isinstance(result, user_pb2.GroupCreateResponse):
            pass
    except Exception as e:
        LoggerTraceback.error("Resource Decorator exception", e, logger)
    return True



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.sales import address_pb2 as _address_pb2
from omni.pro.protos.v1.sales import channel_pb2 as _channel_pb2
from omni.pro.protos.v1.sales import client_pb2 as _client_pb2
from omni.pro.protos.v1.sales import country_pb2 as _country_pb2
from omni.pro.protos.v1.sales import currency_pb2 as _currency_pb2
from omni.pro.protos.v1.sales import payment_method_pb2 as _payment_method_pb2
from omni.pro.protos.v1.sales import state_pb2 as _state_pb2
from omni.pro.protos.v1.sales import warehouse_pb2 as _warehouse_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Sale(_message.Message):
    __slots__ = [
        "id",
        "name",
        "date_order",
        "origin",
        "channel",
        "currency",
        "confirm_date",
        "client",
        "bill_address",
        "country",
        "warehouse",
        "json_order",
        "state",
        "active",
        "external_id",
        "object_audit",
        "payment_method",
        "orders",
        "pickings",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATE_ORDER_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_DATE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    BILL_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    JSON_ORDER_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_METHOD_FIELD_NUMBER: _ClassVar[int]
    ORDERS_FIELD_NUMBER: _ClassVar[int]
    PICKINGS_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    date_order: _timestamp_pb2.Timestamp
    origin: str
    channel: _channel_pb2.Channel
    currency: _currency_pb2.Currency
    confirm_date: _timestamp_pb2.Timestamp
    client: _client_pb2.Client
    bill_address: _address_pb2.Address
    country: _country_pb2.Country
    warehouse: _warehouse_pb2.Warehouse
    json_order: str
    state: _state_pb2.State
    active: _wrappers_pb2.BoolValue
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    payment_method: _payment_method_pb2.PaymentMethod
    orders: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    pickings: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        date_order: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        origin: _Optional[str] = ...,
        channel: _Optional[_Union[_channel_pb2.Channel, _Mapping]] = ...,
        currency: _Optional[_Union[_currency_pb2.Currency, _Mapping]] = ...,
        confirm_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        client: _Optional[_Union[_client_pb2.Client, _Mapping]] = ...,
        bill_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ...,
        country: _Optional[_Union[_country_pb2.Country, _Mapping]] = ...,
        warehouse: _Optional[_Union[_warehouse_pb2.Warehouse, _Mapping]] = ...,
        json_order: _Optional[str] = ...,
        state: _Optional[_Union[_state_pb2.State, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
        payment_method: _Optional[_Union[_payment_method_pb2.PaymentMethod, _Mapping]] = ...,
        orders: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        pickings: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
    ) -> None: ...

class SaleIntegration(_message.Message):
    __slots__ = [
        "order_details",
        "oms_rules",
        "client_details",
        "payment",
        "order_items",
        "shipping",
        "additional_info",
    ]
    ORDER_DETAILS_FIELD_NUMBER: _ClassVar[int]
    OMS_RULES_FIELD_NUMBER: _ClassVar[int]
    CLIENT_DETAILS_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_FIELD_NUMBER: _ClassVar[int]
    ORDER_ITEMS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_INFO_FIELD_NUMBER: _ClassVar[int]
    order_details: _struct_pb2.Struct
    oms_rules: _struct_pb2.Struct
    client_details: _struct_pb2.Struct
    payment: _struct_pb2.Struct
    order_items: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    shipping: _struct_pb2.Struct
    additional_info: _struct_pb2.Struct
    def __init__(
        self,
        order_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        oms_rules: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        client_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        payment: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        order_items: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        shipping: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        additional_info: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
    ) -> None: ...

class SaleCreateRequest(_message.Message):
    __slots__ = [
        "name",
        "date_order",
        "origin",
        "channel_id",
        "currency_id",
        "confirm_date",
        "client_id",
        "country_id",
        "bill_address_code",
        "warehouse_id",
        "json_order",
        "state_id",
        "external_id",
        "context",
        "payment_method_id",
    ]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATE_ORDER_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_DATE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    BILL_ADDRESS_CODE_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    JSON_ORDER_FIELD_NUMBER: _ClassVar[int]
    STATE_ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    date_order: _timestamp_pb2.Timestamp
    origin: str
    channel_id: int
    currency_id: str
    confirm_date: _timestamp_pb2.Timestamp
    client_id: str
    country_id: str
    bill_address_code: str
    warehouse_id: int
    json_order: str
    state_id: int
    external_id: str
    context: _base_pb2.Context
    payment_method_id: int
    def __init__(
        self,
        name: _Optional[str] = ...,
        date_order: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        origin: _Optional[str] = ...,
        channel_id: _Optional[int] = ...,
        currency_id: _Optional[str] = ...,
        confirm_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        client_id: _Optional[str] = ...,
        country_id: _Optional[str] = ...,
        bill_address_code: _Optional[str] = ...,
        warehouse_id: _Optional[int] = ...,
        json_order: _Optional[str] = ...,
        state_id: _Optional[int] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
        payment_method_id: _Optional[int] = ...,
    ) -> None: ...

class SaleCreateResponse(_message.Message):
    __slots__ = ["sale", "response_standard"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    sale: Sale
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        sale: _Optional[_Union[Sale, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class SaleReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class SaleReadResponse(_message.Message):
    __slots__ = ["sale", "response_standard", "meta_data"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    sale: _containers.RepeatedCompositeFieldContainer[Sale]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    def __init__(
        self,
        sale: _Optional[_Iterable[_Union[Sale, _Mapping]]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
    ) -> None: ...

class SaleUpdateRequest(_message.Message):
    __slots__ = ["sale", "context"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    sale: Sale
    context: _base_pb2.Context
    def __init__(
        self,
        sale: _Optional[_Union[Sale, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class SaleUpdateResponse(_message.Message):
    __slots__ = ["sale", "response_standard"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    sale: Sale
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        sale: _Optional[_Union[Sale, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class SaleDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class SaleDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class SaleCreateIntegrationRequest(_message.Message):
    __slots__ = [
        "order_details",
        "oms_rules",
        "client_details",
        "payment",
        "order_items",
        "shipping",
        "additional_info",
        "context",
    ]
    ORDER_DETAILS_FIELD_NUMBER: _ClassVar[int]
    OMS_RULES_FIELD_NUMBER: _ClassVar[int]
    CLIENT_DETAILS_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_FIELD_NUMBER: _ClassVar[int]
    ORDER_ITEMS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_INFO_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    order_details: _struct_pb2.Struct
    oms_rules: _struct_pb2.Struct
    client_details: _struct_pb2.Struct
    payment: _struct_pb2.Struct
    order_items: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    shipping: _struct_pb2.Struct
    additional_info: _struct_pb2.Struct
    context: _base_pb2.Context
    def __init__(
        self,
        order_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        oms_rules: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        client_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        payment: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        order_items: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        shipping: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        additional_info: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class SaleCreateIntegrationResponse(_message.Message):
    __slots__ = ["sale", "response_standard"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    sale: _struct_pb2.Struct
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        sale: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.sales import order_pb2 as _order_pb2
from omni.pro.protos.v1.sales import product_pb2 as _product_pb2
from omni.pro.protos.v1.sales import tax_pb2 as _tax_pb2
from omni.pro.protos.v1.sales import uom_pb2 as _uom_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class OrderLine(_message.Message):
    __slots__ = [
        "id",
        "order",
        "product",
        "quantity",
        "uom",
        "price_unit",
        "taxes",
        "discount",
        "price_total",
        "sub_total",
        "active",
        "external_id",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    UOM_FIELD_NUMBER: _ClassVar[int]
    PRICE_UNIT_FIELD_NUMBER: _ClassVar[int]
    TAXES_FIELD_NUMBER: _ClassVar[int]
    DISCOUNT_FIELD_NUMBER: _ClassVar[int]
    PRICE_TOTAL_FIELD_NUMBER: _ClassVar[int]
    SUB_TOTAL_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    order: _order_pb2.Order
    product: _product_pb2.Product
    quantity: float
    uom: _uom_pb2.Uom
    price_unit: float
    taxes: _containers.RepeatedCompositeFieldContainer[_tax_pb2.Tax]
    discount: float
    price_total: float
    sub_total: float
    active: _wrappers_pb2.BoolValue
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        order: _Optional[_Union[_order_pb2.Order, _Mapping]] = ...,
        product: _Optional[_Union[_product_pb2.Product, _Mapping]] = ...,
        quantity: _Optional[float] = ...,
        uom: _Optional[_Union[_uom_pb2.Uom, _Mapping]] = ...,
        price_unit: _Optional[float] = ...,
        taxes: _Optional[_Iterable[_Union[_tax_pb2.Tax, _Mapping]]] = ...,
        discount: _Optional[float] = ...,
        price_total: _Optional[float] = ...,
        sub_total: _Optional[float] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class OrderLineCreateRequest(_message.Message):
    __slots__ = [
        "order_id",
        "product_id",
        "quantity",
        "uom_id",
        "price_unit",
        "taxes_id",
        "discount",
        "price_total",
        "sub_total",
        "external_id",
        "context",
    ]
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    UOM_ID_FIELD_NUMBER: _ClassVar[int]
    PRICE_UNIT_FIELD_NUMBER: _ClassVar[int]
    TAXES_ID_FIELD_NUMBER: _ClassVar[int]
    DISCOUNT_FIELD_NUMBER: _ClassVar[int]
    PRICE_TOTAL_FIELD_NUMBER: _ClassVar[int]
    SUB_TOTAL_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    order_id: int
    product_id: str
    quantity: float
    uom_id: str
    price_unit: float
    taxes_id: _containers.RepeatedScalarFieldContainer[int]
    discount: float
    price_total: float
    sub_total: float
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        order_id: _Optional[int] = ...,
        product_id: _Optional[str] = ...,
        quantity: _Optional[float] = ...,
        uom_id: _Optional[str] = ...,
        price_unit: _Optional[float] = ...,
        taxes_id: _Optional[_Iterable[int]] = ...,
        discount: _Optional[float] = ...,
        price_total: _Optional[float] = ...,
        sub_total: _Optional[float] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class OrderLineCreateResponse(_message.Message):
    __slots__ = ["order_line", "response_standard"]
    ORDER_LINE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    order_line: OrderLine
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        order_line: _Optional[_Union[OrderLine, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class OrderLineReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class OrderLineReadResponse(_message.Message):
    __slots__ = ["order_lines", "response_standard", "meta_data"]
    ORDER_LINES_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    order_lines: _containers.RepeatedCompositeFieldContainer[OrderLine]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    def __init__(
        self,
        order_lines: _Optional[_Iterable[_Union[OrderLine, _Mapping]]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
    ) -> None: ...

class OrderLineUpdateRequest(_message.Message):
    __slots__ = ["order_line", "context"]
    ORDER_LINE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    order_line: OrderLine
    context: _base_pb2.Context
    def __init__(
        self,
        order_line: _Optional[_Union[OrderLine, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class OrderLineUpdateResponse(_message.Message):
    __slots__ = ["order_line", "response_standard"]
    ORDER_LINE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    order_line: OrderLine
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        order_line: _Optional[_Union[OrderLine, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class OrderLineDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class OrderLineDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import special_conditions_pb2 as v1_dot_rules_dot_special__conditions__pb2


class SpecialConditionsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SpecialConditionsCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService/SpecialConditionsCreate",
            request_serializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsCreateResponse.FromString,
        )
        self.SpecialConditionsRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService/SpecialConditionsRead",
            request_serializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsReadResponse.FromString,
        )
        self.SpecialConditionsUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService/SpecialConditionsUpdate",
            request_serializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsUpdateResponse.FromString,
        )
        self.SpecialConditionsDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService/SpecialConditionsDelete",
            request_serializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsDeleteResponse.FromString,
        )


class SpecialConditionsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SpecialConditionsCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SpecialConditionsRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SpecialConditionsUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SpecialConditionsDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SpecialConditionsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "SpecialConditionsCreate": grpc.unary_unary_rpc_method_handler(
            servicer.SpecialConditionsCreate,
            request_deserializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsCreateResponse.SerializeToString,
        ),
        "SpecialConditionsRead": grpc.unary_unary_rpc_method_handler(
            servicer.SpecialConditionsRead,
            request_deserializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsReadResponse.SerializeToString,
        ),
        "SpecialConditionsUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.SpecialConditionsUpdate,
            request_deserializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsUpdateResponse.SerializeToString,
        ),
        "SpecialConditionsDelete": grpc.unary_unary_rpc_method_handler(
            servicer.SpecialConditionsDelete,
            request_deserializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class SpecialConditionsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SpecialConditionsCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService/SpecialConditionsCreate",
            v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsCreateRequest.SerializeToString,
            v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SpecialConditionsRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService/SpecialConditionsRead",
            v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsReadRequest.SerializeToString,
            v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SpecialConditionsUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService/SpecialConditionsUpdate",
            v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsUpdateRequest.SerializeToString,
            v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SpecialConditionsDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsService/SpecialConditionsDelete",
            v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsDeleteRequest.SerializeToString,
            v1_dot_rules_dot_special__conditions__pb2.SpecialConditionsDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from typing import ClassVar as _ClassVar
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Field(_message.Message):
    __slots__ = ["key", "x_amz_algorithm", "x_amz_credential", "x_amz_date", "policy", "x_amz_signature"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    X_AMZ_ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    X_AMZ_CREDENTIAL_FIELD_NUMBER: _ClassVar[int]
    X_AMZ_DATE_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    X_AMZ_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    key: str
    x_amz_algorithm: str
    x_amz_credential: str
    x_amz_date: str
    policy: str
    x_amz_signature: str
    def __init__(
        self,
        key: _Optional[str] = ...,
        x_amz_algorithm: _Optional[str] = ...,
        x_amz_credential: _Optional[str] = ...,
        x_amz_date: _Optional[str] = ...,
        policy: _Optional[str] = ...,
        x_amz_signature: _Optional[str] = ...,
    ) -> None: ...

class UploadFile(_message.Message):
    __slots__ = ["url", "fields"]
    URL_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    url: str
    fields: Field
    def __init__(self, url: _Optional[str] = ..., fields: _Optional[_Union[Field, _Mapping]] = ...) -> None: ...

class UploadXlsxRequest(_message.Message):
    __slots__ = ["file_name", "context"]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    file_name: str
    context: _base_pb2.Context
    def __init__(
        self, file_name: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class UploadXlsxResponse(_message.Message):
    __slots__ = ["response_standard", "result"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    result: UploadFile
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        result: _Optional[_Union[UploadFile, _Mapping]] = ...,
    ) -> None: ...



from omni.pro import redis
from omni.pro.aws import AWSCognitoClient, AWSS3Client
from omni.pro.config import Config
from omni.pro.database import DatabaseManager, PostgresDatabaseManager
from omni.pro.logger import LoggerTraceback, configure_logger
from omni.pro.util import Resource

logger = configure_logger(name=__name__)


def resources_decorator(resource_list: list) -> callable:
    def decorador_func(funcion: callable) -> callable:
        def inner(instance, request, context):
            try:
                redis_manager = redis.get_redis_manager()
                context.redis_manager = redis_manager
                if Resource.AWS_COGNITO in resource_list:
                    cognito_params = redis_manager.get_aws_cognito_config(Config.SERVICE_ID, request.context.tenant)
                    # logger.info(f"Cognito params: {cognito_params}")
                    context.cognito_client = AWSCognitoClient(**cognito_params)
                if Resource.AWS_S3 in resource_list:
                    s3_params = redis_manager.get_aws_s3_config(Config.SERVICE_ID, request.context.tenant)
                    # logger.info(f"S3 params: {s3_params}")
                    context.s3_client = AWSS3Client(**s3_params)
                if Resource.MONGODB in resource_list:
                    # logger.info(f"Tenant: {request.context.tenant}, Service ID: {Config.SERVICE_ID}")
                    db_params = redis_manager.get_mongodb_config(Config.SERVICE_ID, request.context.tenant)
                    context.db_name = f"{request.context.tenant}_{db_params.get('name')}"
                    db_params["db"] = db_params.pop("name")
                    # logger.info(f"MongoDB params: {db_params}")
                    context.db_manager = DatabaseManager(**db_params)
                if Resource.POSTGRES in resource_list:
                    # logger.info(f"Tenant: {request.context.tenant}, Service ID: {Config.SERVICE_ID}")
                    db_params = redis_manager.get_postgres_config(Config.SERVICE_ID, request.context.tenant)
                    context.db_name = db_params.get("name")
                    context.pg_db_params = db_params
                    # logger.info(f"Postgres params: {db_params}")
                    context.pg_manager = PostgresDatabaseManager(**db_params)
            except Exception as e:
                LoggerTraceback.error("Resource Decorator exception", e, logger)
            c = funcion(instance, request, context)
            return c

        return inner

    return decorador_func



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.utilities import model_pb2 as v1_dot_utilities_dot_model__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/utilities/event.proto\x12#pro.omni.oms.api.v1.utilities.event\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/utilities/model.proto"\xff\x01\n\x05\x45vent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x39\n\x05model\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model\x12\x11\n\toperation\x18\x05 \x01(\t\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa2\x01\n\x12\x45ventCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x11\n\toperation\x18\x04 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x13\x45ventCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\x05\x65vent\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.event.Event"\xee\x02\n\x10\x45ventReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd5\x01\n\x11\x45ventReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12:\n\x06\x65vents\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.utilities.event.Event"\x87\x01\n\x12\x45ventUpdateRequest\x12\x39\n\x05\x65vent\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.event.Event\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x13\x45ventUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\x05\x65vent\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.event.Event"X\n\x12\x45ventDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13\x45ventDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x9b\x04\n\x0c\x45ventService\x12\x82\x01\n\x0b\x45ventCreate\x12\x37.pro.omni.oms.api.v1.utilities.event.EventCreateRequest\x1a\x38.pro.omni.oms.api.v1.utilities.event.EventCreateResponse"\x00\x12|\n\tEventRead\x12\x35.pro.omni.oms.api.v1.utilities.event.EventReadRequest\x1a\x36.pro.omni.oms.api.v1.utilities.event.EventReadResponse"\x00\x12\x82\x01\n\x0b\x45ventUpdate\x12\x37.pro.omni.oms.api.v1.utilities.event.EventUpdateRequest\x1a\x38.pro.omni.oms.api.v1.utilities.event.EventUpdateResponse"\x00\x12\x82\x01\n\x0b\x45ventDelete\x12\x37.pro.omni.oms.api.v1.utilities.event.EventDeleteRequest\x1a\x38.pro.omni.oms.api.v1.utilities.event.EventDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.event_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_EVENT"]._serialized_start = 143
    _globals["_EVENT"]._serialized_end = 398
    _globals["_EVENTCREATEREQUEST"]._serialized_start = 401
    _globals["_EVENTCREATEREQUEST"]._serialized_end = 563
    _globals["_EVENTCREATERESPONSE"]._serialized_start = 566
    _globals["_EVENTCREATERESPONSE"]._serialized_end = 721
    _globals["_EVENTREADREQUEST"]._serialized_start = 724
    _globals["_EVENTREADREQUEST"]._serialized_end = 1090
    _globals["_EVENTREADRESPONSE"]._serialized_start = 1093
    _globals["_EVENTREADRESPONSE"]._serialized_end = 1306
    _globals["_EVENTUPDATEREQUEST"]._serialized_start = 1309
    _globals["_EVENTUPDATEREQUEST"]._serialized_end = 1444
    _globals["_EVENTUPDATERESPONSE"]._serialized_start = 1447
    _globals["_EVENTUPDATERESPONSE"]._serialized_end = 1602
    _globals["_EVENTDELETEREQUEST"]._serialized_start = 1604
    _globals["_EVENTDELETEREQUEST"]._serialized_end = 1692
    _globals["_EVENTDELETERESPONSE"]._serialized_start = 1694
    _globals["_EVENTDELETERESPONSE"]._serialized_end = 1790
    _globals["_EVENTSERVICE"]._serialized_start = 1793
    _globals["_EVENTSERVICE"]._serialized_end = 2332
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class ExportModelRequest(_message.Message):
    __slots__ = ["model_name", "export_to", "export_type_file", "fields", "context"]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    EXPORT_TO_FIELD_NUMBER: _ClassVar[int]
    EXPORT_TYPE_FILE_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    model_name: str
    export_to: str
    export_type_file: str
    fields: _containers.RepeatedScalarFieldContainer[str]
    context: _base_pb2.Context
    def __init__(
        self,
        model_name: _Optional[str] = ...,
        export_to: _Optional[str] = ...,
        export_type_file: _Optional[str] = ...,
        fields: _Optional[_Iterable[str]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ExportModelResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import timezone_pb2 as v1_dot_utilities_dot_timezone__pb2


class TimezoneServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TimezoneAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.timezone.TimezoneService/TimezoneAdd",
            request_serializer=v1_dot_utilities_dot_timezone__pb2.TimezoneAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_timezone__pb2.TimezoneAddResponse.FromString,
        )
        self.TimezoneRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.timezone.TimezoneService/TimezoneRead",
            request_serializer=v1_dot_utilities_dot_timezone__pb2.TimezoneReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_timezone__pb2.TimezoneReadResponse.FromString,
        )
        self.TimezoneUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.timezone.TimezoneService/TimezoneUpdate",
            request_serializer=v1_dot_utilities_dot_timezone__pb2.TimezoneUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_timezone__pb2.TimezoneUpdateResponse.FromString,
        )
        self.TimezoneDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.timezone.TimezoneService/TimezoneDelete",
            request_serializer=v1_dot_utilities_dot_timezone__pb2.TimezoneDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_timezone__pb2.TimezoneDeleteResponse.FromString,
        )


class TimezoneServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def TimezoneAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TimezoneRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TimezoneUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TimezoneDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_TimezoneServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "TimezoneAdd": grpc.unary_unary_rpc_method_handler(
            servicer.TimezoneAdd,
            request_deserializer=v1_dot_utilities_dot_timezone__pb2.TimezoneAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_timezone__pb2.TimezoneAddResponse.SerializeToString,
        ),
        "TimezoneRead": grpc.unary_unary_rpc_method_handler(
            servicer.TimezoneRead,
            request_deserializer=v1_dot_utilities_dot_timezone__pb2.TimezoneReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_timezone__pb2.TimezoneReadResponse.SerializeToString,
        ),
        "TimezoneUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.TimezoneUpdate,
            request_deserializer=v1_dot_utilities_dot_timezone__pb2.TimezoneUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_timezone__pb2.TimezoneUpdateResponse.SerializeToString,
        ),
        "TimezoneDelete": grpc.unary_unary_rpc_method_handler(
            servicer.TimezoneDelete,
            request_deserializer=v1_dot_utilities_dot_timezone__pb2.TimezoneDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_timezone__pb2.TimezoneDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.timezone.TimezoneService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class TimezoneService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def TimezoneAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.timezone.TimezoneService/TimezoneAdd",
            v1_dot_utilities_dot_timezone__pb2.TimezoneAddRequest.SerializeToString,
            v1_dot_utilities_dot_timezone__pb2.TimezoneAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TimezoneRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.timezone.TimezoneService/TimezoneRead",
            v1_dot_utilities_dot_timezone__pb2.TimezoneReadRequest.SerializeToString,
            v1_dot_utilities_dot_timezone__pb2.TimezoneReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TimezoneUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.timezone.TimezoneService/TimezoneUpdate",
            v1_dot_utilities_dot_timezone__pb2.TimezoneUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_timezone__pb2.TimezoneUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TimezoneDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.timezone.TimezoneService/TimezoneDelete",
            v1_dot_utilities_dot_timezone__pb2.TimezoneDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_timezone__pb2.TimezoneDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/carrier.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/rules/carrier.proto\x12!pro.omni.oms.api.v1.rules.carrier\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xcb\x01\n\x07\x43\x61rrier\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x61rrier_sql_id\x18\x04 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x97\x01\n\x14\x43\x61rrierCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x16\n\x0e\x63\x61rrier_sql_id\x18\x03 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43\x61rrierCreateResponse\x12;\n\x07\x63\x61rrier\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.carrier.Carrier\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf0\x02\n\x12\x43\x61rrierReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd9\x01\n\x13\x43\x61rrierReadResponse\x12<\n\x08\x63\x61rriers\x18\x01 \x03(\x0b\x32*.pro.omni.oms.api.v1.rules.carrier.Carrier\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x01\n\x14\x43\x61rrierUpdateRequest\x12;\n\x07\x63\x61rrier\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.carrier.Carrier\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43\x61rrierUpdateResponse\x12;\n\x07\x63\x61rrier\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.carrier.Carrier\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"f\n\x14\x43\x61rrierDeleteRequest\x12\x16\n\x0e\x63\x61rrier_sql_id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x43\x61rrierDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa5\x04\n\x0e\x43\x61rrierService\x12\x84\x01\n\rCarrierCreate\x12\x37.pro.omni.oms.api.v1.rules.carrier.CarrierCreateRequest\x1a\x38.pro.omni.oms.api.v1.rules.carrier.CarrierCreateResponse"\x00\x12~\n\x0b\x43\x61rrierRead\x12\x35.pro.omni.oms.api.v1.rules.carrier.CarrierReadRequest\x1a\x36.pro.omni.oms.api.v1.rules.carrier.CarrierReadResponse"\x00\x12\x84\x01\n\rCarrierUpdate\x12\x37.pro.omni.oms.api.v1.rules.carrier.CarrierUpdateRequest\x1a\x38.pro.omni.oms.api.v1.rules.carrier.CarrierUpdateResponse"\x00\x12\x84\x01\n\rCarrierDelete\x12\x37.pro.omni.oms.api.v1.rules.carrier.CarrierDeleteRequest\x1a\x38.pro.omni.oms.api.v1.rules.carrier.CarrierDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.carrier_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CARRIER"]._serialized_start = 113
    _globals["_CARRIER"]._serialized_end = 316
    _globals["_CARRIERCREATEREQUEST"]._serialized_start = 319
    _globals["_CARRIERCREATEREQUEST"]._serialized_end = 470
    _globals["_CARRIERCREATERESPONSE"]._serialized_start = 473
    _globals["_CARRIERCREATERESPONSE"]._serialized_end = 632
    _globals["_CARRIERREADREQUEST"]._serialized_start = 635
    _globals["_CARRIERREADREQUEST"]._serialized_end = 1003
    _globals["_CARRIERREADRESPONSE"]._serialized_start = 1006
    _globals["_CARRIERREADRESPONSE"]._serialized_end = 1223
    _globals["_CARRIERUPDATEREQUEST"]._serialized_start = 1226
    _globals["_CARRIERUPDATEREQUEST"]._serialized_end = 1365
    _globals["_CARRIERUPDATERESPONSE"]._serialized_start = 1368
    _globals["_CARRIERUPDATERESPONSE"]._serialized_end = 1527
    _globals["_CARRIERDELETEREQUEST"]._serialized_start = 1529
    _globals["_CARRIERDELETEREQUEST"]._serialized_end = 1631
    _globals["_CARRIERDELETERESPONSE"]._serialized_start = 1633
    _globals["_CARRIERDELETERESPONSE"]._serialized_end = 1731
    _globals["_CARRIERSERVICE"]._serialized_start = 1734
    _globals["_CARRIERSERVICE"]._serialized_end = 2283
# @@protoc_insertion_point(module_scope)



import datetime
import importlib
from datetime import datetime

from google.protobuf import json_format, struct_pb2
from pymongo.cursor import Cursor


# FIXME: change param including_default_value_fields to default_values when invoking util.MessageToDict
def MessageToDict(message, default_values=False, including_default_value_fields=False, **kwargs):
    """
    Converts protobuf message to a JSON dictionary considering the preserving proto field names.
    @param message: The protobuf message to convert.
    @param default_values: If True, fields with default values will be included in the dictionary.
    @param kwargs: Additional arguments to pass to json_format.MessageToDict.
    @return: The JSON dictionary.
    """
    return json_format.MessageToDict(
        message,
        preserving_proto_field_name=True,
        including_default_value_fields=default_values or including_default_value_fields,
        **kwargs,
    )


def format_request(data, request, proto, **kwargs) -> object:
    return json_format.ParseDict(data, getattr(proto, request)(), **kwargs)


def to_value(obj):
    """
    Use condictional expression to convert a object to a `Value`.
    """
    if isinstance(obj, dict):
        if "_id" in obj:
            obj["id"] = obj.pop("_id")
        return struct_pb2.Value(struct_value=to_struct(obj))
    elif isinstance(obj, list) or isinstance(obj, Cursor):
        return struct_pb2.Value(list_value=to_list_value(obj))
    elif isinstance(obj, bool):
        return struct_pb2.Value(bool_value=obj)
    elif isinstance(obj, int) or isinstance(obj, float):
        return struct_pb2.Value(number_value=obj)
    elif obj is None:
        return struct_pb2.Value(null_value=struct_pb2.NullValue.NULL_VALUE)
    else:
        return struct_pb2.Value(string_value=str(obj))


def to_struct(d):
    return struct_pb2.Struct(fields={k: to_value(v) for k, v in d.items()})


def to_list_value(lst):
    """Converts a list of dictionaries to a `ListValue`.

    Args:
      lst: A list of dictionaries.

    Returns:
      A `ListValue`.
    """
    return struct_pb2.ListValue(values=[to_value(x) for x in lst])


def format_datetime_to_iso(datetime_obj: datetime):
    """
    Convert a datetime object to ISO 8601 format ('YYYY-MM-DDTHH:MM:SSZ').

    Args:
        datetime_obj (datetime.datetime): The datetime object to be formatted.

    Returns:
        str:
            A string representing the datetime in ISO 8601 format.

    Example:
        # Convert a datetime object to ISO 8601 format
        dt = datetime.datetime(2023, 8, 22, 14, 30, 0)
        formatted_datetime = format_datetime_to_iso(dt)
        print(formatted_datetime)
    """
    formatted_datetime = datetime_obj.strftime("%Y-%m-%dT%H:%M:%SZ")
    return formatted_datetime


def model_to_proto(model, fields, serialize_proto=None, **kwargs):
    """
    Converts a model instance to its corresponding protocol buffer (protobuf) representation.

    This function takes an instance of a model and a list of field names, and uses a serialization
    prototype (serialize_proto) to generate a corresponding protobuf object. The prototype is dynamically
    imported based on the provided name.

    Args:
        model (BaseModel):
            The model instance to be converted. This can be any object with accessible attributes.
        fields (list of str):
            A list of field names (strings) that will be copied from the model to the protobuf object.
        serialize_proto (str):
            The full name of the protobuf prototype to be used for serialization. This name is used
            to dynamically import the corresponding protobuf class.
        **kwargs:
            Additional arguments that can be passed to handle specific cases or advanced configurations
            in the serialization process.

    Returns:
        An instance of the protobuf prototype with the model fields assigned.

    Example:
        # Example of converting a model to a protobuf object
        class MyModel:
            name = "test"
            age = 25

        model_instance = MyModel()
        proto_obj = model_to_proto(model_instance, ["name", "age"], "my_package.MyProto")
        print(proto_obj)
    """
    proto_class_name = serialize_proto.split(".")[-1]
    serialize_proto = getattr(
        importlib.import_module("omni.pro.protos.{0}".format(serialize_proto.split(f".{proto_class_name}")[0])),
        proto_class_name,
    )
    if model:
        return serialize_proto(**{key: getattr(model, key) for key in fields})



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import location_pb2 as v1_dot_rules_dot_location__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!v1/rules/delivery_warehouse.proto\x12,pro.omni.oms.api.v1.rules.delivery_warehouse\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/rules/warehouse.proto\x1a\x17v1/rules/location.proto"\xa7\x02\n\x12WarehouseHierarchy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x41\n\twarehouse\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12>\n\x08location\x18\x04 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12\x19\n\x11quantity_security\x18\x05 \x01(\x02\x12\x10\n\x08sequence\x18\x06 \x01(\x05\x12\x32\n\x0esequence_order\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tgift_code\x18\x08 \x01(\t"\xd5\x01\n\x18WarehouseHierarchyCreate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x13\n\x0blocation_id\x18\x04 \x01(\x05\x12\x19\n\x11quantity_security\x18\x05 \x01(\x02\x12\x10\n\x08sequence\x18\x06 \x01(\x05\x12\x32\n\x0esequence_order\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tgift_code\x18\x08 \x01(\t"\xb3\x02\n\x11\x44\x65liveryWarehouse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12#\n\x1bhierarchy_warehouse_sort_by\x18\x03 \x01(\t\x12]\n\x13transfer_warehouses\x18\x04 \x03(\x0b\x32@.pro.omni.oms.api.v1.rules.delivery_warehouse.WarehouseHierarchy\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x85\x02\n\x1e\x44\x65liveryWarehouseCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x1bhierarchy_warehouse_sort_by\x18\x02 \x01(\t\x12\x63\n\x13transfer_warehouses\x18\x03 \x03(\x0b\x32\x46.pro.omni.oms.api.v1.rules.delivery_warehouse.WarehouseHierarchyCreate\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc9\x01\n\x1f\x44\x65liveryWarehouseCreateResponse\x12[\n\x12\x64\x65livery_warehouse\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfa\x02\n\x1c\x44\x65liveryWarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x83\x02\n\x1d\x44\x65liveryWarehouseReadResponse\x12\\\n\x13\x64\x65livery_warehouses\x18\x01 \x03(\x0b\x32?.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouse\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb5\x01\n\x1e\x44\x65liveryWarehouseUpdateRequest\x12[\n\x12\x64\x65livery_warehouse\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc9\x01\n\x1f\x44\x65liveryWarehouseUpdateResponse\x12[\n\x12\x64\x65livery_warehouse\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"d\n\x1e\x44\x65liveryWarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"l\n\x1f\x44\x65liveryWarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x94\x01\n\x1b\x41\x64\x64TransferWarehouseRequest\x12\x1d\n\x15\x64\x65livery_warehouse_id\x18\x01 \x01(\t\x12\x1e\n\x16warehouse_herarchy_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc6\x01\n\x1c\x41\x64\x64TransferWarehouseResponse\x12[\n\x12\x64\x65livery_warehouse\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x97\x01\n\x1eRemoveTransferWarehouseRequest\x12\x1d\n\x15\x64\x65livery_warehouse_id\x18\x01 \x01(\t\x12\x1e\n\x16warehouse_herarchy_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc9\x01\n\x1fRemoveTransferWarehouseResponse\x12[\n\x12\x64\x65livery_warehouse\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xed\x08\n\x18\x44\x65liveryWarehouseService\x12\xb8\x01\n\x17\x44\x65liveryWarehouseCreate\x12L.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseCreateRequest\x1aM.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseCreateResponse"\x00\x12\xb2\x01\n\x15\x44\x65liveryWarehouseRead\x12J.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseReadRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseReadResponse"\x00\x12\xb8\x01\n\x17\x44\x65liveryWarehouseUpdate\x12L.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseUpdateRequest\x1aM.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseUpdateResponse"\x00\x12\xb8\x01\n\x17\x44\x65liveryWarehouseDelete\x12L.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseDeleteRequest\x1aM.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseDeleteResponse"\x00\x12\xaf\x01\n\x14\x41\x64\x64TransferWarehouse\x12I.pro.omni.oms.api.v1.rules.delivery_warehouse.AddTransferWarehouseRequest\x1aJ.pro.omni.oms.api.v1.rules.delivery_warehouse.AddTransferWarehouseResponse"\x00\x12\xb8\x01\n\x17RemoveTransferWarehouse\x12L.pro.omni.oms.api.v1.rules.delivery_warehouse.RemoveTransferWarehouseRequest\x1aM.pro.omni.oms.api.v1.rules.delivery_warehouse.RemoveTransferWarehouseResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSEHIERARCHY"]._serialized_start = 186
    _globals["_WAREHOUSEHIERARCHY"]._serialized_end = 481
    _globals["_WAREHOUSEHIERARCHYCREATE"]._serialized_start = 484
    _globals["_WAREHOUSEHIERARCHYCREATE"]._serialized_end = 697
    _globals["_DELIVERYWAREHOUSE"]._serialized_start = 700
    _globals["_DELIVERYWAREHOUSE"]._serialized_end = 1007
    _globals["_DELIVERYWAREHOUSECREATEREQUEST"]._serialized_start = 1010
    _globals["_DELIVERYWAREHOUSECREATEREQUEST"]._serialized_end = 1271
    _globals["_DELIVERYWAREHOUSECREATERESPONSE"]._serialized_start = 1274
    _globals["_DELIVERYWAREHOUSECREATERESPONSE"]._serialized_end = 1475
    _globals["_DELIVERYWAREHOUSEREADREQUEST"]._serialized_start = 1478
    _globals["_DELIVERYWAREHOUSEREADREQUEST"]._serialized_end = 1856
    _globals["_DELIVERYWAREHOUSEREADRESPONSE"]._serialized_start = 1859
    _globals["_DELIVERYWAREHOUSEREADRESPONSE"]._serialized_end = 2118
    _globals["_DELIVERYWAREHOUSEUPDATEREQUEST"]._serialized_start = 2121
    _globals["_DELIVERYWAREHOUSEUPDATEREQUEST"]._serialized_end = 2302
    _globals["_DELIVERYWAREHOUSEUPDATERESPONSE"]._serialized_start = 2305
    _globals["_DELIVERYWAREHOUSEUPDATERESPONSE"]._serialized_end = 2506
    _globals["_DELIVERYWAREHOUSEDELETEREQUEST"]._serialized_start = 2508
    _globals["_DELIVERYWAREHOUSEDELETEREQUEST"]._serialized_end = 2608
    _globals["_DELIVERYWAREHOUSEDELETERESPONSE"]._serialized_start = 2610
    _globals["_DELIVERYWAREHOUSEDELETERESPONSE"]._serialized_end = 2718
    _globals["_ADDTRANSFERWAREHOUSEREQUEST"]._serialized_start = 2721
    _globals["_ADDTRANSFERWAREHOUSEREQUEST"]._serialized_end = 2869
    _globals["_ADDTRANSFERWAREHOUSERESPONSE"]._serialized_start = 2872
    _globals["_ADDTRANSFERWAREHOUSERESPONSE"]._serialized_end = 3070
    _globals["_REMOVETRANSFERWAREHOUSEREQUEST"]._serialized_start = 3073
    _globals["_REMOVETRANSFERWAREHOUSEREQUEST"]._serialized_end = 3224
    _globals["_REMOVETRANSFERWAREHOUSERESPONSE"]._serialized_start = 3227
    _globals["_REMOVETRANSFERWAREHOUSERESPONSE"]._serialized_end = 3428
    _globals["_DELIVERYWAREHOUSESERVICE"]._serialized_start = 3431
    _globals["_DELIVERYWAREHOUSESERVICE"]._serialized_end = 4564
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.utilities import event_pb2 as _event_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Webhook(_message.Message):
    __slots__ = ["id", "event", "url", "method", "format", "log", "active", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    event: _event_pb2.Event
    url: str
    method: str
    format: str
    log: _wrappers_pb2.BoolValue
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        event: _Optional[_Union[_event_pb2.Event, _Mapping]] = ...,
        url: _Optional[str] = ...,
        method: _Optional[str] = ...,
        format: _Optional[str] = ...,
        log: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class WebhookCreateRequest(_message.Message):
    __slots__ = ["event_id", "url", "method", "format", "log", "context"]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    url: str
    method: str
    format: str
    log: _wrappers_pb2.BoolValue
    context: _base_pb2.Context
    def __init__(
        self,
        event_id: _Optional[str] = ...,
        url: _Optional[str] = ...,
        method: _Optional[str] = ...,
        format: _Optional[str] = ...,
        log: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WebhookCreateResponse(_message.Message):
    __slots__ = ["response_standard", "webhook"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    WEBHOOK_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    webhook: Webhook
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        webhook: _Optional[_Union[Webhook, _Mapping]] = ...,
    ) -> None: ...

class WebhookReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WebhookReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "webhooks"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    WEBHOOKS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    webhooks: _containers.RepeatedCompositeFieldContainer[Webhook]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        webhooks: _Optional[_Iterable[_Union[Webhook, _Mapping]]] = ...,
    ) -> None: ...

class WebhookUpdateRequest(_message.Message):
    __slots__ = ["webhook", "context"]
    WEBHOOK_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    webhook: Webhook
    context: _base_pb2.Context
    def __init__(
        self,
        webhook: _Optional[_Union[Webhook, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WebhookUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "webhook"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    WEBHOOK_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    webhook: Webhook
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        webhook: _Optional[_Union[Webhook, _Mapping]] = ...,
    ) -> None: ...

class WebhookDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class WebhookDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/sales/state.proto\x12\x1fpro.omni.oms.api.v1.sales.state\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xfb\x01\n\x05State\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12%\n\x04\x66low\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb1\x01\n\x12StateCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13StateCreateResponse\x12\x35\n\x05state\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.state.State\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xee\x02\n\x10StateReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11StateReadResponse\x12\x36\n\x06states\x18\x01 \x03(\x0b\x32&.pro.omni.oms.api.v1.sales.state.State\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x83\x01\n\x12StateUpdateRequest\x12\x35\n\x05state\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.state.State\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13StateUpdateResponse\x12\x35\n\x05state\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.state.State\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"X\n\x12StateDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13StateDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cStateService\x12z\n\x0bStateCreate\x12\x33.pro.omni.oms.api.v1.sales.state.StateCreateRequest\x1a\x34.pro.omni.oms.api.v1.sales.state.StateCreateResponse"\x00\x12t\n\tStateRead\x12\x31.pro.omni.oms.api.v1.sales.state.StateReadRequest\x1a\x32.pro.omni.oms.api.v1.sales.state.StateReadResponse"\x00\x12z\n\x0bStateUpdate\x12\x33.pro.omni.oms.api.v1.sales.state.StateUpdateRequest\x1a\x34.pro.omni.oms.api.v1.sales.state.StateUpdateResponse"\x00\x12z\n\x0bStateDelete\x12\x33.pro.omni.oms.api.v1.sales.state.StateDeleteRequest\x1a\x34.pro.omni.oms.api.v1.sales.state.StateDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.state_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STATE"]._serialized_start = 139
    _globals["_STATE"]._serialized_end = 390
    _globals["_STATECREATEREQUEST"]._serialized_start = 393
    _globals["_STATECREATEREQUEST"]._serialized_end = 570
    _globals["_STATECREATERESPONSE"]._serialized_start = 573
    _globals["_STATECREATERESPONSE"]._serialized_end = 724
    _globals["_STATEREADREQUEST"]._serialized_start = 727
    _globals["_STATEREADREQUEST"]._serialized_end = 1093
    _globals["_STATEREADRESPONSE"]._serialized_start = 1096
    _globals["_STATEREADRESPONSE"]._serialized_end = 1305
    _globals["_STATEUPDATEREQUEST"]._serialized_start = 1308
    _globals["_STATEUPDATEREQUEST"]._serialized_end = 1439
    _globals["_STATEUPDATERESPONSE"]._serialized_start = 1442
    _globals["_STATEUPDATERESPONSE"]._serialized_end = 1593
    _globals["_STATEDELETEREQUEST"]._serialized_start = 1595
    _globals["_STATEDELETEREQUEST"]._serialized_end = 1683
    _globals["_STATEDELETERESPONSE"]._serialized_start = 1685
    _globals["_STATEDELETERESPONSE"]._serialized_end = 1781
    _globals["_STATESERVICE"]._serialized_start = 1784
    _globals["_STATESERVICE"]._serialized_end = 2288
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper

DESCRIPTOR: _descriptor.FileDescriptor

class Object(_message.Message):
    __slots__ = ["code_name", "code"]
    CODE_NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    code_name: str
    code: str
    def __init__(self, code_name: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...

class GroupBy(_message.Message):
    __slots__ = ["name_field"]
    NAME_FIELD_FIELD_NUMBER: _ClassVar[int]
    name_field: str
    def __init__(self, name_field: _Optional[str] = ...) -> None: ...

class SortBy(_message.Message):
    __slots__ = ["name_field", "type"]

    class SortType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        ASC: _ClassVar[SortBy.SortType]
        DESC: _ClassVar[SortBy.SortType]
    ASC: SortBy.SortType
    DESC: SortBy.SortType
    NAME_FIELD_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    name_field: str
    type: SortBy.SortType
    def __init__(
        self, name_field: _Optional[str] = ..., type: _Optional[_Union[SortBy.SortType, str]] = ...
    ) -> None: ...

class Fields(_message.Message):
    __slots__ = ["name_field"]
    NAME_FIELD_FIELD_NUMBER: _ClassVar[int]
    name_field: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name_field: _Optional[_Iterable[str]] = ...) -> None: ...

class Filter(_message.Message):
    __slots__ = ["filter"]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    filter: str
    def __init__(self, filter: _Optional[str] = ...) -> None: ...

class Paginated(_message.Message):
    __slots__ = ["offset", "limit"]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    offset: int
    limit: int
    def __init__(self, offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class LinkPage(_message.Message):
    __slots__ = ["type", "link"]

    class LinkType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        NEXT: _ClassVar[LinkPage.LinkType]
        PREV: _ClassVar[LinkPage.LinkType]
        LAST: _ClassVar[LinkPage.LinkType]
        FIRST: _ClassVar[LinkPage.LinkType]
    NEXT: LinkPage.LinkType
    PREV: LinkPage.LinkType
    LAST: LinkPage.LinkType
    FIRST: LinkPage.LinkType
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LINK_FIELD_NUMBER: _ClassVar[int]
    type: LinkPage.LinkType
    link: str
    def __init__(self, type: _Optional[_Union[LinkPage.LinkType, str]] = ..., link: _Optional[str] = ...) -> None: ...

class MetaData(_message.Message):
    __slots__ = ["total", "offset", "limit", "count", "link_page"]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    LINK_PAGE_FIELD_NUMBER: _ClassVar[int]
    total: int
    offset: int
    limit: int
    count: int
    link_page: _containers.RepeatedCompositeFieldContainer[LinkPage]
    def __init__(
        self,
        total: _Optional[int] = ...,
        offset: _Optional[int] = ...,
        limit: _Optional[int] = ...,
        count: _Optional[int] = ...,
        link_page: _Optional[_Iterable[_Union[LinkPage, _Mapping]]] = ...,
    ) -> None: ...

class ResponseStandard(_message.Message):
    __slots__ = ["success", "message", "status_code", "message_code"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    status_code: int
    message_code: str
    def __init__(
        self,
        success: bool = ...,
        message: _Optional[str] = ...,
        status_code: _Optional[int] = ...,
        message_code: _Optional[str] = ...,
    ) -> None: ...

class ObjectAudit(_message.Message):
    __slots__ = ["created_by", "updated_by", "deleted_by", "created_at", "updated_at", "deleted_at"]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    DELETED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    created_by: str
    updated_by: str
    deleted_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    deleted_at: _timestamp_pb2.Timestamp
    def __init__(
        self,
        created_by: _Optional[str] = ...,
        updated_by: _Optional[str] = ...,
        deleted_by: _Optional[str] = ...,
        created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        deleted_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
    ) -> None: ...

class Context(_message.Message):
    __slots__ = ["tenant", "user"]
    TENANT_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    tenant: str
    user: str
    def __init__(self, tenant: _Optional[str] = ..., user: _Optional[str] = ...) -> None: ...

class ObjectResponse(_message.Message):
    __slots__ = ["id", "name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    def __init__(self, id: _Optional[int] = ..., name: _Optional[str] = ...) -> None: ...
